@@ -211,6 +211,7 @@ def separate_by_mode(text: str) -> Iterator[Tuple[str, Mode]]:
 
 def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optional[str]]] = None) -> None:
     command = node.token
+    modifier = node.modifier
 
     if command == commands.SUBSTACK:
         parent = SubElement(parent, "mstyle", scriptlevel="1")
@@ -252,6 +253,12 @@ def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optio
         tag = "munder"
     elif command == commands.SUBSUP and node.children is not None and node.children[0].token == commands.GCD:
         tag = "munderover"
+    elif command == commands.SUPERSCRIPT and modifier == commands.LIMITS:
+        tag = "mover"
+    elif command == commands.SUBSCRIPT and modifier == commands.LIMITS:
+        tag = "munder"
+    elif command == commands.SUBSUP and modifier == commands.LIMITS:
+        tag = "munderover"
 
     element = SubElement(parent, tag, attributes)
 
@@ -260,6 +267,8 @@ def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optio
     elif command in (commands.MOD, commands.PMOD):
         element.text = "mod"
         SubElement(parent, "mspace", width="0.333em")
+    elif command == commands.BMOD:
+        element.text = "mod"
     elif node.text is not None:
         if command == commands.MIDDLE:
             element.text = "&#x{};".format(convert_symbol(node.text))
